/*
 *  Copyright 2010 Chris Pheby
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.jadira.bindings.core;

import java.lang.annotation.Annotation;
import java.net.URL;
import java.util.Set;

import org.jadira.bindings.core.api.FromStringUnmarshaller;
import org.jadira.bindings.core.api.StringBinding;
import org.jadira.bindings.core.api.ToStringMarshaller;

public interface StringBinder {
    
    public abstract void registerConfiguration(URL nextLocation);

    public abstract <T> String convertToString(T object);

    public abstract <T> String convertToString(T object, Class<? extends Annotation> qualifier);

    public abstract <T> T convertFromString(Class<T> cls, String str);

    public abstract <T> T convertFromString(Class<T> cls, String str, Class<? extends Annotation> qualifier);

    public <T> StringBinding<T> findBinding(final Class<T> cls);
    
    public <T> ToStringMarshaller<T> findMarshaller(final Class<T> cls);
    
    public <T> FromStringUnmarshaller<T> findUnmarshaller(final Class<T> cls);
    
    public <T> StringBinding<T> findBinding(final Class<T> cls, final Class<? extends Annotation> qualifier);
    
    public <T> ToStringMarshaller<T> findMarshaller(final Class<T> cls, final Class<? extends Annotation> qualifier);
    
    public <T> FromStringUnmarshaller<T> findUnmarshaller(final Class<T> cls, final Class<? extends Annotation> qualifier);
    
    <T> void register(final Class<T> cls, StringBinding<T> converter);
    
    <T> void register(final Class<T> cls, ToStringMarshaller<T> converter);
    
    <T> void register(final Class<T> cls, FromStringUnmarshaller<T> converter);

    <T> void register(final Class<T> cls, StringBinding<T> converter, Class<? extends Annotation> qualifier);
    
    <T> void register(final Class<T> cls, ToStringMarshaller<T> converter, Class<? extends Annotation> qualifier);
    
    <T> void register(final Class<T> cls, FromStringUnmarshaller<T> converter, Class<? extends Annotation> qualifier);

    Set<Class<?>> determineMarshallableClasses();
    
    Set<Class<?>> determineUnmarshallableClasses();
}