/*
 *  Copyright 2010 Chris Pheby
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.jadira.bindings.core.general;

import org.jadira.bindings.core.api.FromStringUnmarshaller;
import org.jadira.bindings.core.api.StringBinding;
import org.jadira.bindings.core.api.ToStringMarshaller;

/**
 * String binding that supports a toString contract, and fromString contract
 * @param <T> the type of the class for the conversion
 */
public class CompositeStringBinding<T> implements StringBinding<T> {

    private final ToStringMarshaller<T> marshal;
    
    private final FromStringUnmarshaller<T> unmarshal;
    
    public CompositeStringBinding(ToStringMarshaller<T> marshal, FromStringUnmarshaller<T> unmarshal) {
        
        if (unmarshal == null) {
            throw new IllegalStateException("Unmarshaller may not be null");
        }
        if (marshal == null) {
            throw new IllegalStateException("Marshaller may not be null");
        }
        
        this.unmarshal = unmarshal;
        this.marshal = marshal;
    }

    public String marshal(T object) {
        return marshal.marshal(object);
    }

    public T unmarshal(String inputString) {
        return unmarshal.unmarshal(inputString);
    }
    
}