/*
 *  Copyright 2010 Christopher Pheby
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.jadira.bindings.core.loader;

import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

import org.jadira.bindings.core.annotation.DefaultBinding;

public class Binding {

    private Class<?> bindingClass;
    private Class<?> targetClass;
    private Class<? extends Annotation> qualifier = DefaultBinding.class;
    private Method toStringMethod;
    private Method fromStringMethod;
    private Constructor<?> fromStringConstructor;

    public Binding(Class<?> bindingClass, Class<?> targetClass, Class<? extends Annotation> qualifier, Method toStringMethod, Method fromStringMethod, Constructor<?> fromStringConstructor) {
        this.bindingClass = bindingClass;
        this.targetClass = targetClass;
        this.qualifier = qualifier;
        this.toStringMethod = toStringMethod;
        this.fromStringMethod = fromStringMethod;
        this.fromStringConstructor = fromStringConstructor;
    }

    public Class<?> getBindingClass() {
        return bindingClass;
    }
    
    public Class<?> getTargetClass() {
        return targetClass;
    }

    public Class<? extends Annotation> getQualifier() {
        return qualifier;
    }
    
    public Method getToStringMethod() {
        return toStringMethod;
    }
    
    public Method getFromStringMethod() {
        return fromStringMethod;
    }
    
    public Constructor<?> getFromStringConstructor() {
        return fromStringConstructor;
    }
}
