/*
 *  Copyright 2010 Chris Pheby
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.jadira.bindings.core.spi;

import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

/**
 * Defines an extension point to the binding framework for adding new binding capabilities
 */
public interface BindingProvider {

    /**
     * Match a method that can perform a toString operation
     * @param cls The class being inspected
     * @param qualifier The qualifier for the operation
     * @return A method or null
     */
    public Method findToStringMethod(final Class<?> cls, final Class<? extends Annotation> qualifier);
 
    /**
     * Match a constructor that can perform a fromString operation
     * @param cls The class being inspected
     * @param qualifier The qualifier for the operation
     * @return A constructor or null
     */
    public <T> Constructor<T> findFromStringConstructor(Class<T> cls, Class<? extends Annotation> qualifier);
    
    /**
     * Match a method that can perform a fromString operation
     * @param cls The class being inspected
     * @param qualifier The qualifier for the operation
     * @return A method or null
     */
    public Method findFromStringMethod(Class<?> cls, Class<? extends Annotation> qualifier);
}
